@@ -1,10 +1,10 @@
 # File modes.
-O_RDONLY = 00000000
-O_WRONLY = 00000001
-O_RDWR   = 00000002
-O_CREAT  = 00000100
-O_EXCL   = 00000200
-O_TRUNC  = 00001000
+O_RDONLY = 0o0
+O_WRONLY = 0o1
+O_RDWR   = 0o2
+O_CREAT  = 0o100
+O_EXCL   = 0o200
+O_TRUNC  = 0o1000
 
 # Access modes 
 FA_WRITE = 'w'
